@@ -37,6 +37,10 @@ class Coverage(FormatSwitchingBaseTable):
 
 	# manual implementation to get rid of glyphID dependencies
 
+	def populateDefaults(self, propagator=None):
+		if not hasattr(self, 'glyphs'):
+			self.glyphs = []
+
 	def postRead(self, rawTable, font):
 		if self.Format == 1:
 			# TODO only allow glyphs that are valid?
@@ -136,6 +140,10 @@ class Coverage(FormatSwitchingBaseTable):
 
 class VarIdxMap(BaseTable):
 
+	def populateDefaults(self, propagator=None):
+		if not hasattr(self, 'mapping'):
+			self.mapping = []
+
 	def postRead(self, rawTable, font):
 		assert (rawTable['EntryFormat'] & 0xFFC0) == 0
 		self.mapping = rawTable['mapping']
@@ -197,30 +205,12 @@ class VarIdxMap(BaseTable):
 		mapping.append((outer << 16) | inner)
 
 
-class VarData(BaseTable):
-
-	def preWrite(self, font):
-		rawTable = self.__dict__.copy()
-
-		# TODO Remove this abstraction/optimization and move it varLib.builder?
-
-		numShorts = 0
-		count = len(self.VarRegionIndex)
-		for item in getattr(self, 'Item', []):
-			assert len(item) == count, ("Item length mismatch", len(item), count)
-			for i in range(count - 1, numShorts - 1, -1):
-				if not (-128 <= item[i] <= 127):
-					numShorts = i + 1
-					break
-			if numShorts == count:
-				break
-
-		rawTable['NumShorts'] = numShorts
-		return rawTable
-
-
 class SingleSubst(FormatSwitchingBaseTable):
 
+	def populateDefaults(self, propagator=None):
+		if not hasattr(self, 'mapping'):
+			self.mapping = {}
+
 	def postRead(self, rawTable, font):
 		mapping = {}
 		input = _getGlyphsFromCoverageTable(rawTable["Coverage"])
@@ -295,6 +285,11 @@ class SingleSubst(FormatSwitchingBaseTable):
 
 
 class MultipleSubst(FormatSwitchingBaseTable):
+
+	def populateDefaults(self, propagator=None):
+		if not hasattr(self, 'mapping'):
+			self.mapping = {}
+
 	def postRead(self, rawTable, font):
 		mapping = {}
 		if self.Format == 1:
@@ -356,7 +351,7 @@ class MultipleSubst(FormatSwitchingBaseTable):
 			return
 
                 # TTX v3.1 and later.
-		outGlyphs = attrs["out"].split(",")
+		outGlyphs = attrs["out"].split(",") if attrs["out"] else []
 		mapping[attrs["in"]] = [g.strip() for g in outGlyphs]
 
 	@staticmethod
@@ -368,6 +363,10 @@ class MultipleSubst(FormatSwitchingBaseTable):
 
 class ClassDef(FormatSwitchingBaseTable):
 
+	def populateDefaults(self, propagator=None):
+		if not hasattr(self, 'classDefs'):
+			self.classDefs = {}
+
 	def postRead(self, rawTable, font):
 		classDefs = {}
 		glyphOrder = font.getGlyphOrder()
@@ -419,19 +418,19 @@ class ClassDef(FormatSwitchingBaseTable):
 			assert 0, "unknown format: %s" % self.Format
 		self.classDefs = classDefs
 
-	def preWrite(self, font):
+	def _getClassRanges(self, font):
 		classDefs = getattr(self, "classDefs", None)
 		if classDefs is None:
-			classDefs = self.classDefs = {}
-		format = 2
-		rawTable = {"ClassRangeRecord": []}
+			self.classDefs = {}
+			return
 		getGlyphID = font.getGlyphID
 		items = []
 		for glyphName, cls in classDefs.items():
-			if not cls: continue
+			if not cls:
+				continue
 			items.append((getGlyphID(glyphName), glyphName, cls))
-		items.sort()
 		if items:
+			items.sort()
 			last, lastName, lastCls = items[0]
 			ranges = [[lastCls, last, lastName]]
 			for glyphID, glyphName, cls in items[1:]:
@@ -442,7 +441,13 @@ class ClassDef(FormatSwitchingBaseTable):
 				lastName = glyphName
 				lastCls = cls
 			ranges[-1].extend([last, lastName])
+			return ranges
 
+	def preWrite(self, font):
+		format = 2
+		rawTable = {"ClassRangeRecord": []}
+		ranges = self._getClassRanges(font)
+		if ranges:
 			startGlyph = ranges[0][1]
 			endGlyph = ranges[-1][3]
 			glyphCount = endGlyph - startGlyph + 1
@@ -485,6 +490,10 @@ class ClassDef(FormatSwitchingBaseTable):
 
 class AlternateSubst(FormatSwitchingBaseTable):
 
+	def populateDefaults(self, propagator=None):
+		if not hasattr(self, 'alternates'):
+			self.alternates = {}
+
 	def postRead(self, rawTable, font):
 		alternates = {}
 		if self.Format == 1:
@@ -511,7 +520,7 @@ class AlternateSubst(FormatSwitchingBaseTable):
 		cov.glyphs = [ item[1] for item in items]
 		alternates = []
 		setList = [ item[-1] for item in items]
-		for  set in setList:
+		for set in setList:
 			alts = AlternateSet()
 			alts.Alternate = set
 			alternates.append(alts)
@@ -528,7 +537,7 @@ class AlternateSubst(FormatSwitchingBaseTable):
 		for glyphName, alternates in items:
 			xmlWriter.begintag("AlternateSet", glyph=glyphName)
 			xmlWriter.newline()
-			for alt in sorted(alternates):
+			for alt in alternates:
 				xmlWriter.simpletag("Alternate", glyph=alt)
 				xmlWriter.newline()
 			xmlWriter.endtag("AlternateSet")
@@ -551,6 +560,10 @@ class AlternateSubst(FormatSwitchingBaseTable):
 
 class LigatureSubst(FormatSwitchingBaseTable):
 
+	def populateDefaults(self, propagator=None):
+		if not hasattr(self, 'ligatures'):
+			self.ligatures = {}
+
 	def postRead(self, rawTable, font):
 		ligatures = {}
 		if self.Format == 1:
@@ -843,7 +856,7 @@ def splitPairPos(oldSubTable, newSubTable, overflowRecord):
 		oldSubTable.Class1Record = records[:oldCount]
 
 		newSubTable.Coverage.glyphs = [g for g in coverage if g in newGlyphs]
-		newSubTable.ClassDef1.classDefs = {k:(v-oldCount) for k,v in classDefs.items() if v >= oldCount}
+		newSubTable.ClassDef1.classDefs = {k:(v-oldCount) for k,v in classDefs.items() if v > oldCount}
 		newSubTable.Class1Record = records[oldCount:]
 
 		oldSubTable.Class1Count = len(oldSubTable.Class1Record)
